cmoncrawl.processor.pipeline.streamer — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.processor.pipeline.streamer

Classes

`BaseStreamerFile`(root, max_directory_size, ...) | Abstract Class which defines the basic functionality of a file streamer
`IStreamer`() | Base class for all outstreamers
`StreamerDummy`() | Dummy Streamer which keeps the output is memory
`StreamerFileHTML`(root, max_directory_size) |
`StreamerFileJSON`(root, max_directory_size, ...) |